@@ -1,22 +1,13 @@
-
 #pragma once
 
-#ifndef ON
-#define ON 1
-#endif
+#define OBS_VERSION "29.1.3-1"
 
-#ifndef OFF
-#define OFF 0
-#endif
-
-#define OBS_VERSION "28.0.3-2"
-#define OBS_VERSION_CANONICAL "28.0.3"
+#define OBS_VERSION_CANONICAL "29.1.3"
 #define OBS_DATA_PATH "share/obs"
-#define OBS_INSTALL_PREFIX "/usr/"
+#define OBS_PLUGIN_PATH "lib/obs-plugins"
 #define OBS_PLUGIN_DESTINATION "lib/obs-plugins"
-#define OBS_QT_VERSION 6
 
-/* #undef LINUX_PORTABLE */
+/* #undef OBS_COMMIT */
 #define GIO_FOUND
 #define PULSEAUDIO_FOUND
 #define XCB_XINPUT_FOUND
